@@ -11,7 +11,7 @@ use Test2::Mock();
 
 use base 'Exporter';
 
-our $VERSION = '0.000125';
+our $VERSION = '0.000128';
 
 our @CARP_NOT = (__PACKAGE__, 'Test2::Mock');
 our @EXPORT = qw/mock mocked/;
@@ -320,7 +320,7 @@ plugins in ways L<Mock::Quick> would be unable to.
             replace_or_inject => sub { ... },
         ],
 
-        track => $bool, # enable/disable tracking again to effect mocks made after this point
+        track => $bool, # enable/disable tracking again to affect mocks made after this point
         ..., # Argument keys may be repeated
     );
 
@@ -352,11 +352,11 @@ depending on how it is used. If you are not comfortable with a function that
 has a lot of potential behaviors, you can use one of the other functions
 directly.
 
-=item $mock = mocked($object)
+=item @mocks = mocked($object)
 
-=item $mock = mocked($class)
+=item @mocks = mocked($class)
 
-Check if an object or class is mocked. If it is mocked the C<$mock> object
+Check if an object or class is mocked. If it is mocked the C<$mock> object(s)
 (L<Test2::Mock>) will be returned.
 
 =item $mock = mock $class => ( ... );
@@ -511,7 +511,7 @@ Mock objects are instances of L<Test2::Mock>. See it for their methods.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<https://github.com/Test-More/Test2-Suite/>.
+L<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -536,6 +536,6 @@ Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
